@@ -1,22 +1,21 @@
-
-simSurv	<- function(cluster=NULL, x, beta.true, alpha.true, kappa.true, sigmaV.true=NULL, cens)
+simSurv	<- function(id=NULL, x, beta.true, alpha.true, kappa.true, sigmaV.true=NULL, cens)
 {
-    if(!is.null(cluster) & is.null(sigmaV.true)){
-        print("sigmaV.true must be given to simulate correated data")
+    if(!is.null(id) & is.null(sigmaV.true)){
+        stop("sigmaV.true must be given to simulate correated data")
     }
     else
     {
         n <- dim(x)[1]
         p <- dim(x)[2]
         
-        if(is.null(cluster))
+        if(is.null(id))
         {
             LP	<- as.vector(beta.true %*% t(x))
         }
-        if(!is.null(cluster))
+        if(!is.null(id))
         {
-            J <- length(unique(cluster))
-            nj <- as.vector(table(cluster))
+            J <- length(unique(id))
+            nj <- as.vector(table(id))
             
             V <- matrix(rnorm(J, 0, sqrt(sigmaV.true)), J, 1) # J X 1
             
