@@ -1,4 +1,71 @@
 
+extern void BpeMvnCorScr_logMLH_i(int i,
+                                  gsl_vector *beta1,
+                                  gsl_vector *beta2,
+                                  gsl_vector *beta3,
+                                  gsl_vector *xbeta1,
+                                  gsl_vector *xbeta2,
+                                  gsl_vector *xbeta3,
+                                  double theta,
+                                  gsl_vector *lambda1,
+                                  gsl_vector *lambda2,
+                                  gsl_vector *lambda3,
+                                  gsl_vector *s1,
+                                  gsl_vector *s2,
+                                  gsl_vector *s3,
+                                  gsl_vector *V1,
+                                  gsl_vector *V2,
+                                  gsl_vector *V3,
+                                  gsl_vector *survTime1,
+                                  gsl_vector *survTime2,
+                                  gsl_vector *survEvent1,
+                                  gsl_vector *survEvent2,
+                                  gsl_vector *case01,
+                                  gsl_vector *case11,
+                                  gsl_matrix *survCov1,
+                                  gsl_matrix *survCov2,
+                                  gsl_matrix *survCov3,
+                                  gsl_vector *cluster,
+                                  int K1,
+                                  int K2,
+                                  int K3,
+                                  double *val);
+
+
+
+extern void BpeMvnCorScr_logMLH(gsl_vector *beta1,
+                                gsl_vector *beta2,
+                                gsl_vector *beta3,
+                                gsl_vector *xbeta1,
+                                gsl_vector *xbeta2,
+                                gsl_vector *xbeta3,
+                                double theta,
+                                gsl_vector *lambda1,
+                                gsl_vector *lambda2,
+                                gsl_vector *lambda3,
+                                gsl_vector *s1,
+                                gsl_vector *s2,
+                                gsl_vector *s3,
+                                gsl_vector *V1,
+                                gsl_vector *V2,
+                                gsl_vector *V3,
+                                gsl_vector *survTime1,
+                                gsl_vector *survTime2,
+                                gsl_vector *survEvent1,
+                                gsl_vector *survEvent2,
+                                gsl_vector *case01,
+                                gsl_vector *case11,
+                                gsl_matrix *survCov1,
+                                gsl_matrix *survCov2,
+                                gsl_matrix *survCov3,
+                                gsl_vector *cluster,
+                                int K1,
+                                int K2,
+                                int K3,
+                                double *val);
+
+
+
 
 extern void BpeMvnCorScr_logf_i(int i,
                                 gsl_vector *beta1,
