@@ -23,44 +23,46 @@
 
 /* */
 void BpeScrSMmcmc(double survData[],
-                    int *n,
-                    int *p1,
-                    int *p2,
-                    int *p3,
-                    double hyperParams[],
-                    double startValues[],
-                    double mcmcParams[],
-                    int *numReps,
-                    int *thin,
-                    double *burninPerc,
-                    int *nGam_save,          
-                    double samples_beta1[],
-                    double samples_beta2[],
-                    double samples_beta3[],
-                    double samples_mu_lam1[],
-                    double samples_mu_lam2[],
-                    double samples_mu_lam3[],
-                    double samples_sigSq_lam1[],
-                    double samples_sigSq_lam2[],
-                    double samples_sigSq_lam3[],
-                    double samples_J1[],
-                    double samples_J2[],
-                    double samples_J3[],
-                    double samples_s1[],
-                    double samples_s2[],
-                    double samples_s3[],
-                    double samples_theta[],
-                    double samples_gamma[],
-                    double samples_misc[],
-                    double lambda1_fin[],
-                    double lambda2_fin[],
+                  int *n,
+                  int *p1,
+                  int *p2,
+                  int *p3,
+                  double hyperParams[],
+                  double startValues[],
+                  double mcmcParams[],
+                  int *numReps,
+                  int *thin,
+                  double *burninPerc,
+                  int *nGam_save,
+                  double samples_beta1[],
+                  double samples_beta2[],
+                  double samples_beta3[],
+                  double samples_mu_lam1[],
+                  double samples_mu_lam2[],
+                  double samples_mu_lam3[],
+                  double samples_sigSq_lam1[],
+                  double samples_sigSq_lam2[],
+                  double samples_sigSq_lam3[],
+                  double samples_J1[],
+                  double samples_J2[],
+                  double samples_J3[],
+                  double samples_s1[],
+                  double samples_s2[],
+                  double samples_s3[],
+                  double samples_theta[],
+                  double samples_gamma[],
+                  double samples_misc[],
+                  double lambda1_fin[],
+                  double lambda2_fin[],
                   double lambda3_fin[],
+                  double dev[],
+                  double invLH[],
                   double moveVec[])
 {
     GetRNGstate();
     
     
-    time_t now;    
+    time_t now;
     
     int i, j, M;
     
@@ -138,7 +140,7 @@ void BpeScrSMmcmc(double survData[],
     gsl_vector *yStar = gsl_vector_calloc(*n);
     gsl_vector_memcpy(yStar, survTime2);
     gsl_vector_sub(yStar, survTime1);
-     
+    
     /* Hyperparameters */
     
     double a1        = hyperParams[0];
@@ -182,10 +184,10 @@ void BpeScrSMmcmc(double survData[],
     for(j = 0; j < num_s_propBI1; j++) gsl_vector_set(s_propBI1, j, mcmcParams[18+j]);
     for(j = 0; j < num_s_propBI2; j++) gsl_vector_set(s_propBI2, j, mcmcParams[18+num_s_propBI1+j]);
     for(j = 0; j < num_s_propBI3; j++) gsl_vector_set(s_propBI3, j, mcmcParams[18+num_s_propBI1+num_s_propBI2+j]);
-   
+    
     
     /* time points where lambda values are stored  */
-
+    
     int nTime_lambda1 = mcmcParams[15];
     int nTime_lambda2 = mcmcParams[16];
     int nTime_lambda3 = mcmcParams[17];
@@ -208,7 +210,7 @@ void BpeScrSMmcmc(double survData[],
     }
     
     double mhProp_theta_var  = mcmcParams[18+num_s_propBI1+num_s_propBI2+num_s_propBI3+nTime_lambda1+nTime_lambda2+nTime_lambda3];
-  
+    
     
     
     
@@ -230,7 +232,7 @@ void BpeScrSMmcmc(double survData[],
     {
         for(j = 0; j < *p3; j++) gsl_vector_set(beta3, j, startValues[j + *p1 + *p2]);
     }
-
+    
     
     int J1              = startValues[*p1 + *p2 + *p3];
     int J2              = startValues[*p1 + *p2 + *p3 + 1];
@@ -256,7 +258,7 @@ void BpeScrSMmcmc(double survData[],
     for(j = 0; j < (J1+1); j++) gsl_vector_set(lambda1, j, startValues[*p1 + *p2 + *p3 + 10 + *n + j]);
     for(j = 0; j < (J2+1); j++) gsl_vector_set(lambda2, j, startValues[*p1 + *p2 + *p3 + 10 + *n + (J1+1) + j]);
     for(j = 0; j < (J3+1); j++) gsl_vector_set(lambda3, j, startValues[*p1 + *p2 + *p3 + 10 + *n + (J1+1) + (J2+1) + j]);
-        
+    
     gsl_vector *s1       = gsl_vector_calloc(J1_max+1);
     gsl_vector *s2       = gsl_vector_calloc(J2_max+1);
     gsl_vector *s3       = gsl_vector_calloc(J3_max+1);
@@ -270,12 +272,12 @@ void BpeScrSMmcmc(double survData[],
     gsl_blas_dgemv(CblasNoTrans, 1, survCov1, beta1, 0, xbeta1);
     gsl_blas_dgemv(CblasNoTrans, 1, survCov2, beta2, 0, xbeta2);
     gsl_blas_dgemv(CblasNoTrans, 1, survCov3, beta3, 0, xbeta3);
-
-
-
+    
+    
+    
     
     /* Calculating Sigma_lam (from W and Q) */
-
+    
     
     gsl_matrix *Sigma_lam1       = gsl_matrix_calloc(J1_max+1, J1_max+1);
     gsl_matrix *Sigma_lam2       = gsl_matrix_calloc(J2_max+1, J2_max+1);
@@ -289,11 +291,11 @@ void BpeScrSMmcmc(double survData[],
     gsl_matrix *Q2               = gsl_matrix_calloc(J2_max+1, J2_max+1);
     gsl_matrix *W3               = gsl_matrix_calloc(J3_max+1, J3_max+1);
     gsl_matrix *Q3               = gsl_matrix_calloc(J3_max+1, J3_max+1);
-
+    
     cal_Sigma(Sigma_lam1, invSigma_lam1, W1, Q1, s1, c_lam1, J1);
     cal_Sigma(Sigma_lam2, invSigma_lam2, W2, Q2, s2, c_lam2, J2);
     cal_Sigma(Sigma_lam3, invSigma_lam3, W3, Q3, s3, c_lam3, J3);
-
+    
     
     /* Variables required for storage of samples */
     
@@ -311,6 +313,14 @@ void BpeScrSMmcmc(double survData[],
     int accept_DI3      = 0;
     int accept_theta    = 0;
     
+    double logLH;
+    
+    gsl_vector *invLH_vec = gsl_vector_calloc(*n);
+    gsl_vector *invLH_mean = gsl_vector_calloc(*n);
+    gsl_vector *cpo_vec = gsl_vector_calloc(*n);
+    
+    double invLHval;
+    
     /* Compute probabilities for various types of moves */
     
     double pRP1, pRP2, pRP3, pBH1, pBH2, pBH3, pSP1, pSP2, pSP3, pBI1, pBI2, pBI3, pDI1, pDI2, pDI3, pFP, pDP, choice;
@@ -345,7 +355,7 @@ void BpeScrSMmcmc(double survData[],
     
     for(j = 0; j < J1_max; j++) gsl_vector_set(rho_lam1_vec, j, C1/(gsl_vector_get(pB1, j) + gsl_vector_get(pD1, j)));
     for(j = 0; j < J2_max; j++) gsl_vector_set(rho_lam2_vec, j, C2/(gsl_vector_get(pB2, j) + gsl_vector_get(pD2, j)));
-    for(j = 0; j < J3_max; j++) gsl_vector_set(rho_lam3_vec, j, C3/(gsl_vector_get(pB3, j) + gsl_vector_get(pD3, j)));    
+    for(j = 0; j < J3_max; j++) gsl_vector_set(rho_lam3_vec, j, C3/(gsl_vector_get(pB3, j) + gsl_vector_get(pD3, j)));
     
     rho_lam1 = gsl_vector_min(rho_lam1_vec);
     rho_lam2 = gsl_vector_min(rho_lam2_vec);
@@ -392,7 +402,7 @@ void BpeScrSMmcmc(double survData[],
             pBI3 = 0;
             pDI3 = rho_lam3 * 2;
         }
-            
+        
         pDP = 0.2;
         
         double probSub = (1 - pDP - pBI1 - pBI2 - pBI3 - pDI1 - pDI2 - pDI3)/(numUpdate-7);
@@ -407,10 +417,10 @@ void BpeScrSMmcmc(double survData[],
         pSP2 = probSub;
         pSP3 = probSub;
         pFP  = probSub;
-    
+        
         /* selecting a move */
         /* move: 1=RP1, 2=RP2, 3=RP3, 4=BH1, 5=BH2, 6=BH3, 7=SP1, 8=SP2, 9=SP3, 10=FP,
-                    11=DP, 12=BI1, 13=BI2, 14=BI3, 15=DI1, 16=DI2, 17=DI3 */
+         11=DP, 12=BI1, 13=BI2, 14=BI3, 15=DI1, 16=DI2, 17=DI3 */
         
         choice  = runif(0, 1);
         move    = 1;
@@ -436,7 +446,7 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating regression parameter: beta1 */
         
-
+        
         
         if(move == 1)
         {
@@ -446,7 +456,7 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating regression parameter: beta2 */
         
-
+        
         
         if(move == 2)
         {
@@ -459,7 +469,7 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating regression parameter: beta3 */
         
-
+        
         
         if(move == 3)
         {
@@ -467,11 +477,11 @@ void BpeScrSMmcmc(double survData[],
         }
         
         
-
+        
         /* updating log-baseline hazard function parameter: lambda1 */
         
-
-      
+        
+        
         
         if(move == 4)
         {
@@ -480,13 +490,13 @@ void BpeScrSMmcmc(double survData[],
         
         
         
-
+        
         
         
         /* updating log-baseline hazard function parameter: lambda2 */
         
-       
-
+        
+        
         
         if(move == 5)
         {
@@ -498,8 +508,8 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating log-baseline hazard function parameter: lambda3 */
         
-      
-   
+        
+        
         
         if(move == 6)
         {
@@ -507,13 +517,13 @@ void BpeScrSMmcmc(double survData[],
         }
         
         
-
+        
         
         
         
         /* updating second stage survival components: mu_lam1 and sigSq_lam1 */
         
-
+        
         
         if(move == 7)
         {
@@ -524,8 +534,8 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating second stage survival components: mu_lam2 and sigSq_lam2 */
         
-
-   
+        
+        
         
         if(move == 8)
         {
@@ -535,7 +545,7 @@ void BpeScrSMmcmc(double survData[],
         
         /* updating second stage survival components: mu_lam3 and sigSq_lam3 */
         
-  
+        
         
         if(move == 9)
         {
@@ -545,9 +555,9 @@ void BpeScrSMmcmc(double survData[],
         
         
         /* updating frailty parameter: gamma */
-
-
-
+        
+        
+        
         
         if(move == 10)
         {
@@ -556,8 +566,8 @@ void BpeScrSMmcmc(double survData[],
         
         
         /* updating variance parameter: theta */
-       
-
+        
+        
         
         
         
@@ -572,7 +582,7 @@ void BpeScrSMmcmc(double survData[],
         
         /* Updating the number of splits and their positions: J1 and s1 (Birth move) */
         
-
+        
         
         if(move == 12)
         {
@@ -604,13 +614,13 @@ void BpeScrSMmcmc(double survData[],
         
         /* Updating the number of splits and their positions: J1 and s1 (Death move) */
         
-
+        
         
         if(move == 15)
         {
             BscrSM_updateDI1(s1, &J1, &accept_DI1, survTime1, survEvent1, gamma, xbeta1, Sigma_lam1, invSigma_lam1, W1, Q1, lambda1, s_propBI1, num_s_propBI1, delPert1, alpha1, c_lam1, mu_lam1, sigSq_lam1, s1_max, J1_max);
         }
-
+        
         /* Updating the number of splits and their positions: J2 and s2 (Death move) */
         
         
@@ -633,10 +643,10 @@ void BpeScrSMmcmc(double survData[],
         }
         
         
-
+        
         /* Storing posterior samples */
         
-
+        
         if( ( (M+1) % *thin ) == 0 && (M+1) > (*numReps * *burninPerc))
         {
             StoreInx = (M+1)/(*thin) - (*numReps * *burninPerc)/(*thin);
@@ -654,7 +664,7 @@ void BpeScrSMmcmc(double survData[],
                 for(j = 0; j < *p3; j++) samples_beta3[(StoreInx - 1) * (*p3) + j] = gsl_vector_get(beta3, j);
             }
             
-            samples_theta[StoreInx - 1] = theta;            
+            samples_theta[StoreInx - 1] = theta;
             
             for(i = 0; i < nTime_lambda1; i++)
             {
@@ -666,7 +676,7 @@ void BpeScrSMmcmc(double survData[],
                 lambda1_fin[(StoreInx - 1) * (nTime_lambda1) + i] = gsl_vector_get(lambda1, j);
             }
             
-
+            
             for(i = 0; i < nTime_lambda2; i++)
             {
                 j = 0;
@@ -676,7 +686,7 @@ void BpeScrSMmcmc(double survData[],
                 }
                 lambda2_fin[(StoreInx - 1) * (nTime_lambda2) + i] = gsl_vector_get(lambda2, j);
             }
-
+            
             
             
             for(i = 0; i < nTime_lambda3; i++)
@@ -688,16 +698,16 @@ void BpeScrSMmcmc(double survData[],
                 }
                 lambda3_fin[(StoreInx - 1) * (nTime_lambda3) + i] = gsl_vector_get(lambda3, j);
             }
-             
-                                    /* */
-
+            
+            /* */
+            
             
             samples_mu_lam1[StoreInx - 1] = mu_lam1;
             samples_mu_lam2[StoreInx - 1] = mu_lam2;
             samples_mu_lam3[StoreInx - 1] = mu_lam3;
             samples_sigSq_lam1[StoreInx - 1] = sigSq_lam1;
             samples_sigSq_lam2[StoreInx - 1] = sigSq_lam2;
-            samples_sigSq_lam3[StoreInx - 1] = sigSq_lam3;   
+            samples_sigSq_lam3[StoreInx - 1] = sigSq_lam3;
             samples_J1[StoreInx - 1] = J1;
             samples_J2[StoreInx - 1] = J2;
             samples_J3[StoreInx - 1] = J3;
@@ -730,9 +740,33 @@ void BpeScrSMmcmc(double survData[],
                 }
             }
             
-  
+            /* deviance */
+            
+            BpeScrSM_logMLH(beta1, beta2, beta3, xbeta1, xbeta2, xbeta3, theta, lambda1, lambda2, lambda3, s1, s2, s3, survTime1, survTime2, yStar, survEvent1, survEvent2, case01, case11, survCov1, survCov2, survCov3, J1, J2, J3, &logLH);
+            
+            dev[StoreInx - 1] = -2*logLH;
+            
+            /* CPO_i */
+            
+            for(i = 0; i < *n; i++)
+            {
+                BpeScrSM_logMLH_i(i, beta1, beta2, beta3, xbeta1, xbeta2, xbeta3, theta, lambda1, lambda2, lambda3, s1, s2, s3, survTime1, survTime2, yStar, survEvent1, survEvent2, case01, case11, survCov1, survCov2, survCov3, J1, J2, J3, &invLHval);
+                
+                invLHval = 1/exp(invLHval);
+                gsl_vector_set(invLH_vec, i, invLHval);
+                
+            }
+            
+            gsl_vector_scale(invLH_mean, (double) StoreInx - 1);
+            gsl_vector_add(invLH_mean, invLH_vec);
+            gsl_vector_scale(invLH_mean, (double)1/StoreInx);
+            
+            for(i = 0; i < *n; i++)
+            {
+                gsl_vector_set(cpo_vec, i, 1/gsl_vector_get(invLH_mean, i));
+            }
         }
-
+        
         
         if(M == (*numReps - 1))
         {
@@ -748,7 +782,7 @@ void BpeScrSMmcmc(double survData[],
             {
                 for(j = 0; j < *p3; j++) samples_misc[*p1 + *p2 + j] = (int) gsl_vector_get(accept_beta3, j);
             }
-
+            
             samples_misc[*p1 + *p2 + *p3] = accept_BI1;
             samples_misc[*p1 + *p2 + *p3 + 1] = accept_DI1;
             samples_misc[*p1 + *p2 + *p3 + 2] = accept_BI2;
@@ -756,6 +790,11 @@ void BpeScrSMmcmc(double survData[],
             samples_misc[*p1 + *p2 + *p3 + 4] = accept_BI3;
             samples_misc[*p1 + *p2 + *p3 + 5] = accept_DI3;
             samples_misc[*p1 + *p2 + *p3 + 6] = accept_theta;
+            
+            for(i = 0; i < *n; i++)
+            {
+                invLH[i] = gsl_vector_get(invLH_mean, i);
+            }
         }
         
         
@@ -776,14 +815,14 @@ void BpeScrSMmcmc(double survData[],
         
         
         
-          
-    }    
-   
+        
+    }
+    
+    
+    
+    
     
-  
     
-
-
     PutRNGstate();
     return;
     
@@ -795,3 +834,4 @@ void BpeScrSMmcmc(double survData[],
 
 
 
+
